@@ -22,29 +22,26 @@
 #include "kwin4.h"
 
 // Qt includes
-#include <QRadioButton>
+#include <QButtonGroup>
+#include <QFileDialog>
+#include <QGroupBox>
+#include <QIcon>
 #include <QLayout>
+#include <QRadioButton>
+#include <QStatusBar>
 #include <QTimer>
+#include <QVBoxLayout>
 
 // KDE includes
-#include <kvbox.h>
-#include <kstandardgameaction.h>
-#include <kmessagebox.h>
-#include <kfiledialog.h>
+#include <KActionCollection>
+#include <KConfig>
+#include <KConfigDialog>
+#include <KHelpMenu>
 #include <KLocalizedString>
-#include <khelpmenu.h>
-#include <kconfig.h>
-#include "kfourinline_debug.h"
-#include <kstandardaction.h>
-#include <kaction.h>
-#include <kstatusbar.h>
-#include <kconfigdialog.h>
-#include <kactioncollection.h>
-#include <kbuttongroup.h>
-#include <QIcon>
-#include <kstandarddirs.h>
-#include <kglobal.h>
-#include <kselectaction.h>
+#include <KMessageBox>
+#include <KSelectAction>
+#include <KStandardAction>
+#include <KStandardGameAction>
 
 // KGame includes
 #define USE_UNSTABLE_LIBKDEGAMESPRIVATE_API
@@ -61,6 +58,7 @@
 #include "prefs.h"
 #include "ui_settings.h"
 #include "ui_statistics.h"
+#include "kfourinline_debug.h"
 
 // Abbreviations
 #define ACTION(x)   (actionCollection()->action(x))
@@ -71,7 +69,7 @@
 #define UPDATE_TIME  25   /* [ms] */
 
 // Configuration file
-#include <config-src.h>
+#include "config-src.h"
 
 // Construct the main application window
 KWin4App::KWin4App(QWidget *parent)
@@ -89,18 +87,13 @@ KWin4App::KWin4App(QWidget *parent)
   (void)I18N_NOOP2("default name of first player", "Player 1");
   (void)I18N_NOOP2("default name of second player", "Player 2");
 
-  // Add resource type to grafix
-  KGlobal::dirs()->addResourceType("kwin4theme", "appdata", "grafix/");
-
-  #ifndef NDEBUG
-  #ifdef SRC_DIR
-  qCDebug(KFOURINLINE_LOG) << "Found SRC_DIR =" << SRC_DIR;
-  KGlobal::dirs()->addResourceDir("kwin4theme",QStringLiteral(SRC_DIR)+QStringLiteral("/grafix/"));
-  #endif
-  #endif
-
   // Read theme files
-  QStringList themeList =  KGlobal::dirs()->findAllResources("kwin4theme", QStringLiteral("*.desktop"), KStandardDirs::NoDuplicates);
+  QStringList themeList;
+  const QString dir = QStandardPaths::locate(QStandardPaths::DataLocation, "grafix", QStandardPaths::LocateDirectory);
+  const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.desktop"));
+  for (const QString& file : fileNames)
+    themeList.append(dir + '/' + file);
+
   if (themeList.isEmpty())
   {
     KMessageBox::error(this, i18n("Installation error: No theme list found."));
@@ -352,12 +345,13 @@ void KWin4App::initGUI()
   QStringList themes(mThemeFiles.keys());
   themes.sort();
 
-  action = actionCollection()->addAction( QStringLiteral( "theme" ) , new KSelectAction(i18n("Theme" ), this));
-  action->setIcon(QIcon::fromTheme( QStringLiteral( "games-config-theme" )));
-  ((KSelectAction*)action)->setItems(themes);
-  connect(action, &QAction::triggered, this, &KWin4App::changeTheme);
+  KSelectAction *themeAction = new KSelectAction(i18n("Theme" ), this);
+  actionCollection()->addAction( QStringLiteral( "theme" ) , themeAction );
+  themeAction->setIcon(QIcon::fromTheme( QStringLiteral( "games-config-theme" )));
+  themeAction->setItems(themes);
+  connect(themeAction, static_cast<void (KSelectAction::*)(int)>(&KSelectAction::triggered), this, &KWin4App::changeTheme);
   qCDebug(KFOURINLINE_LOG) << "Setting current theme item to" << mThemeIndexNo;
-  ((KSelectAction*)action)->setCurrentItem(mThemeIndexNo);
+  themeAction->setCurrentItem(mThemeIndexNo);
 
   // Debug
   if (global_debug>0)
@@ -427,7 +421,7 @@ void KWin4App::saveProperties(KConfigGroup& grp)
 
   // Save current game?
   QString name = QStringLiteral("current_game")+grp.name();
-  QString filename = KStandardDirs::locateLocal("appdata", name);
+  QString filename = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + '/' + name;
   bool isRunning = (mDoc->gameStatus()==KGame::Run);
   if (isRunning)
   {
@@ -501,7 +495,7 @@ void KWin4App::menuOpenGame()
   QString filter(QStringLiteral("*"));
   QString file(QStringLiteral("/tmp/kwin.save"));
   if (global_debug < 1)
-    file=KFileDialog::getOpenFileName(QUrl(dir),filter,this);
+    file = QFileDialog::getOpenFileName(this, QString(), dir, filter);
   mDoc->load(file,true);
   checkMenus();
 }
@@ -513,7 +507,7 @@ void KWin4App::menuSaveGame()
   QString filter(QStringLiteral("*"));
   QString file(QStringLiteral("/tmp/kwin.save"));
   if (global_debug < 1)
-    file=KFileDialog::getSaveFileName(QUrl(dir),filter,this);
+    file = QFileDialog::getSaveFileName(this, QString(), dir, filter);
   mDoc->save(file);
 }
 
@@ -791,12 +785,13 @@ void KWin4App::configureNetwork()
   dlg.networkConfig()->setDefaultNetworkInfo(host, port);
   dlg.networkConfig()->setDiscoveryInfo(QStringLiteral("_kfourinline._tcp"),Prefs::gamename());
 
-  KVBox *box=dlg.configPage();
+  QWidget *box=dlg.configPage();
   QLayout *l=box->layout();
 
-  mColorGroup=new KButtonGroup(box);
+  mColorGroup=new QGroupBox(box);
+  QButtonGroup *mColorGroupButtonGroup = new QButtonGroup(mColorGroup);
   QVBoxLayout *grouplay=new QVBoxLayout(mColorGroup);
-  connect(mColorGroup, &KButtonGroup::clicked, this, &KWin4App::remoteChanged);
+  connect(mColorGroup, &QGroupBox::clicked, this, &KWin4App::remoteChanged);
   connect(dlg.networkConfig(), &KGameDialogNetworkConfig::signalServerTypeChanged, this, &KWin4App::serverTypeChanged);
 
   QRadioButton *b1 = new QRadioButton(i18n("Black should be played by remote player"), mColorGroup);
@@ -804,7 +799,7 @@ void KWin4App::configureNetwork()
   grouplay->addWidget(b1);
   grouplay->addWidget(b2);
   l->addWidget(mColorGroup);
-  mColorGroup->setSelected(0);
+  mColorGroupButtonGroup->button(0)->setChecked(true);
   remoteChanged(0);
 
   dlg.adjustSize();
